%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Calculate optimized values of Ro, TFR, Atgo, Ay, and SR  
%----------------------------------
%   OPTIMIZING SR
%------------------------------------
ones_vec = ones(size(rho_run));
small_k = KoverY^(1/(1-capShare));
Nsteps = numel(rho_run);
r = capShare/KoverY-delta;
r_neg_ages = (1/(1+r)).^ages;           % exp(-r * ages);
lambda_ages = (1+lambda).^ages;         % exp(lambda * ages);
for i=1:Nsteps
    PC_vector(i) = sum(c_prof.*(exp(-rho_run(i)*ages)).*L);
    PYl_vector(i) = sum(yl_prof.*(exp(-rho_run(i)*ages)).*L);
    Ac_vector(i) = mean_age(ages, L, c_prof, rho_run(i));
    Ayl_vector(i) = mean_age(ages, L, yl_prof, rho_run(i));
    Atgi_vector(i) = mean_age(ages, L, tgi_prof, rho_run(i));
    Atgo_vector(i) = mean_age(ages, L, tgo_prof, rho_run(i));
end
bracket_vector = rho_run +(delta+lambda)*ones_vec;
s_vector = bracket_vector*KoverY;
KoverC = KoverY./(ones_vec-s_vector);
totalY_vector = small_k^capShare*PYl_vector;
Beta_vector = (ones_vec - s_vector).*totalY_vector./PC_vector;
PVC_vector = double(sum(r_neg_ages.*lambda_ages.*L.*c_prof).*Beta_vector);

% These expressions are derivatives of the expressions that we want to
% maximize
izraz_vector_maxPVC = Ac_vector - Ayl_vector - KoverC;
izraz_vector_maxMSR = Ac_vector - Ayl_vector;
izraz_vector_maxMSRG = Atgo_vector - Atgi_vector;
izraz_vector_Golden = Ac_vector-KoverY*(1-capShare)./(ones_vec - s_vector)-Ayl_vector.*(1-capShare)./(ones_vec - s_vector).*(4^capShare*ones_vec - 4*bracket_vector);

%   Calculates optimal values for growths 
%   as well as the mean ages of consumption and labor income
[n_star_PVC, Ac_PVC, Ayl_PVC, growths_PVC] = star(rho_run, Ac_vector, Ayl_vector, izraz_vector_maxPVC);
[n_star_MSR, Ac_MSR, Ayl_MSR, growths_MSR] = star(rho_run, Ac_vector, Ayl_vector, izraz_vector_maxMSR);
[n_star_MSRG, Ac_MSRG, Ayl_MSRG, growths_MSRG] = star(rho_run, Ac_vector, Ayl_vector, izraz_vector_maxMSRG);
[n_star_GLD, Ac_GLD, Ayl_GLD, growths_GLD] = star(rho_run, Ac_vector, Ayl_vector, izraz_vector_Golden);

rho_max = n_star_PVC; %growthsPVC(end); 
[maxPVC ind_max_PVC] = max(PVC_vector);

Ay_fla = mean_age(ages, L, yl_prof, rho_max);
Ac_fla = mean_age(ages, L, c_prof, rho_max);

%    Calculates optimum values of fertility rates and support ratios
[Ro_PVC, TFR_PVC, SR_PVC, Nage_up_PVC] = CalcOptimumFertil(n_star_PVC, mu_act, Ro_act, TFR_act, ageUp, L, yl_prof, c_prof);
[Ro_MSR, TFR_MSR, SR_MSR, Nage_up_MSR] = CalcOptimumFertil(n_star_MSR, mu_act, Ro_act, TFR_act, ageUp, L, yl_prof, c_prof);
[Ro_MSRG, TFR_MSRG, SRG_MSRG, Nage_up_MSRG] = CalcOptimumFertil(n_star_MSRG, mu_act, Ro_act, TFR_act, ageUp, L, tgo_prof, tgi_prof);
[Ro_GLD, TFR_GLD, SR_GLD, Nage_up_GLD] = CalcOptimumFertil(n_star_GLD, mu_act, Ro_act, TFR_act, ageUp, L, yl_prof, c_prof);

%   Calculates additional exit variables
Science_OptFert_formulae_Module

   

