function resulting_vector = asfr_5to1(ASFR_5, min_asfr5, max_asfr5)
%   INPUTS:
%       ASFR_5      5-year age-specific feritility rates (ASFR)
%       min_asfr5   ASFR for the first age group
%       max_asfr5   ASFR for the last age group
%
%   This function extends 5-year age-specific fertility rates in a simple
%   way:
%       provides zero values before the first age group
%       assumes constant values within each age group
%
%   NOTE:   input values are given per 1000 women 
%           resulting values are given per 1 woman

%   set the zero values before the earliest child-bearing age
resulting_vector(1:min_asfr5) = zeros(1,min_asfr5);

%   assign constant feritility rates for ages within an age-group
for age = min_asfr5:5:max_asfr5
    resulting_vector(age+1:age+5)=ASFR_5((age-min_asfr5)/5+1)/1000;
end
