function [promenljiva, allDataFound] = extractNTA_DataS(countriesCalc, yearsCalc, textData, numData, tipPod, MAX_AGE);
%---
%   This function searches for the country and the year of the profile in a
%   small database (here provided in an input Excel file); 
%   When the appropriate matching line is found, 
%       the data are extended to MAX_AGE
%       and then stored in the variable "promenljiva".
%   Once the data is found, the search stops
%   If the appropriate matching line is not found,
%       we assgin NaN to "promenljiva".

%   This function follows the NTA database format

textInd = 2;
if size(textData,1)==size(numData,1)
    numInd = 2;
else
    numInd = 1;
end
countriesDB = textData(textInd:end,1);
yearsDB= numData(numInd:end,1);
unitsDB = textData(textInd:end,6);
NagesDB = numData(numInd:end,7);
DBavailable = numData(numInd:end,11:end);       % profiles start in 11th column

Ncountries = size(countriesCalc,1);
Nx = size(DBavailable,1);
promenljiva = zeros(Ncountries,MAX_AGE+1);
allDataFound = 0;
for coun = 1:Ncountries
    found = 0;
    NTAcount = char(countriesCalc(coun));
    NTAyear = yearsCalc(coun);
    for counListed = 1:Nx
        Xcount = char(countriesDB(counListed));
        Xyear = yearsDB(counListed);
        if numel(NTAcount)==numel(Xcount)
            if NTAcount==Xcount
                if NTAyear==Xyear
                    %   both country name and the profile year match: 
                    %       data are extracted
                    promenljiva(coun,1:NagesDB(counListed)) = DBavailable(counListed,1:NagesDB(counListed))*NTAunit(unitsDB(counListed));
                    %       data are extended to MAX_AGE
                    if tipPod(1:2)=='DN'    % for the population variable, assign zeros at extended ages 
                        promenljiva(coun,NagesDB(counListed)+1:MAX_AGE+1)= 0;
                    else                    % for the lifecycle variables, assign highest age value at extended ages
                        promenljiva(coun,NagesDB(counListed)+1:MAX_AGE+1)= DBavailable(counListed,NagesDB(counListed))*NTAunit(unitsDB(counListed));
                    end
                    found= 1;
                    break
                end
            end
        end
    end
    if (found==0)       % display message if the data were not found
        display(['Could not find ' tipPod ' data for ' NTAcount ' in year ' num2str(NTAyear)])
        for pozic = 1:MAX_AGE+1
            promenljiva(coun,pozic) = NaN;
        end
    end
    allDataFound = allDataFound + found;
end
